[PATCH BlueZ] device: Fix not probing drivers at startup

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

 



From: Luiz Augusto von Dentz <luiz.von.dentz@xxxxxxxxx>

Patch 67a26abe53bf ("profile: Add probe_on_discover flag") introduced a
regression which prevents drivers to be properly loaded at startup since
at that point they are not connected when code shall testing if
the devide is temporary instead.
---
 src/device.c | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/src/device.c b/src/device.c
index 19ae03f7d98a..ecd385cf813a 100644
--- a/src/device.c
+++ b/src/device.c
@@ -3933,10 +3933,10 @@ static bool device_match_profile(struct btd_device *device,
 	if (profile->remote_uuid == NULL)
 		return false;
 
 	/* Don't match if device was just discovered (not connected) and the
 	 * profile don't have probe_on_discover flag set.
 	 */
-	if (!btd_device_is_connected(device) && !profile->probe_on_discover)
+	if (device->temporary && !profile->probe_on_discover)
 		return false;
 
 	if (g_slist_find_custom(uuids, profile->remote_uuid,
@@ -3933,10 +3933,10 @@ static bool device_match_profile(struct btd_device *device,
 		return false;
 
-	/* Don't match if device was just discovered (not connected) and the
+	/* Don't match if device was just discovered, is temporary, and the
 	 * profile don't have probe_on_discover flag set.
 	 */
-- 
2.41.0




[Index of Archives]     [Bluez Devel]     [Linux Wireless Networking]     [Linux Wireless Personal Area Networking]     [Linux ATH6KL]     [Linux USB Devel]     [Linux Media Drivers]     [Linux Audio Users]     [Linux Kernel]     [Linux SCSI]     [Big List of Linux Books]

  Powered by Linux